Monetary Policy Models 
======================= 
 
This section includes planned models for monetary policy. Contributions are welcome! 
 
- Taylor Rule 
- Balanced Approach Rule 
- First Difference Rule 
- McCallum Rule 
- Orphanides Rule 
- Friedman Rule 
- Interest Rate Smoothing Models 
